==> haskell-bifunctors-5.6.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bifunctors
version:              5.6.1
visibility:           public
id:                   bifunctors-5.6.1-LfpqHZxWXAbEzwimmPLIG8
key:                  bifunctors-5.6.1-LfpqHZxWXAbEzwimmPLIG8
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/bifunctors/
synopsis:             Bifunctors
description:          Bifunctors.
category:             Data, Functors
abi:                  0416d3b7cf409ccf80f6005171c60180
exposed:              True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biap Data.Bifunctor.Biff
    Data.Bifunctor.Clown Data.Bifunctor.Fix Data.Bifunctor.Flip
    Data.Bifunctor.Functor Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Sum Data.Bifunctor.TH
    Data.Bifunctor.Tannen Data.Bifunctor.Wrapped

hidden-modules:       Data.Bifunctor.TH.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bifunctors-5.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bifunctors-5.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bifunctors-5.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bifunctors
hs-libraries:         HSbifunctors-5.6.1-LfpqHZxWXAbEzwimmPLIG8
depends:
    assoc-1.1.1-ECHUyXuI4DU7saXDIs2gf3 base-4.17.2.1
    comonad-5.0.9-DcjlGJ2nFITBh9RczgN9OW containers-0.6.7
    foldable1-classes-compat-0.1-LSwPO9j7hUo2HZCyUFGgTZ
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html:         /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bifunctors-5.6.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bifunctors
version:              5.6.1
visibility:           public
id:                   bifunctors-5.6.1-I8D4o411398wBAYLWU3Py
key:                  bifunctors-5.6.1-I8D4o411398wBAYLWU3Py
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/bifunctors/
synopsis:             Bifunctors
description:          Bifunctors.
category:             Data, Functors
abi:                  b0f0e46689e7488b6f0c5588a9664451
exposed:              True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biap Data.Bifunctor.Biff
    Data.Bifunctor.Clown Data.Bifunctor.Fix Data.Bifunctor.Flip
    Data.Bifunctor.Functor Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Sum Data.Bifunctor.TH
    Data.Bifunctor.Tannen Data.Bifunctor.Wrapped

hidden-modules:       Data.Bifunctor.TH.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/bifunctors-5.6.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bifunctors-5.6.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bifunctors-5.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bifunctors
hs-libraries:         HSbifunctors-5.6.1-I8D4o411398wBAYLWU3Py
depends:
    assoc-1.1.1-ECHUyXuI4DU7saXDIs2gf3 base-4.17.2.1
    comonad-5.0.9-4R4IfV9XZS88cmPqlpNv0r containers-0.6.7
    foldable1-classes-compat-0.1-APdbJB36DZpDzu2crD4jkx
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C template-haskell-2.19.0.0
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html:         /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
